@@ -1,14 +1,23 @@
 import pandas as pd
 
+import gspread
+
+from oauth2client.service_account import ServiceAccountCredentials
+
+from googleapiclient.discovery import build
+
 """ 
 Read google sheet as dataframe
-Usage example: read_gsheet("https://sheet.google.com/45qwd3533")
+
+
+If you read with API, you need to use spreadsheetId and credentials (it is the json file in same notebook folder).
+you also need to add the account email associated to the credentials as user shared in the google sheet.
+
 """
+def read_gsheet(spreadsheetId = None, url = None, credentials = None, sheet = None):
+    
 
-
-def read_gsheet(url, credentials = None, sheet = None):
-
-    if credentials != True:
+    if url and credentials != True:
 
         gc = gspread.service_account(credentials)
 
@@ -28,9 +37,22 @@ def read_gsheet(url, credentials = None, sheet = None):
         df = pd.DataFrame(data, columns = headers)
 
 
-    #else: 
+    else: 
 
-        #df = ##chiamata API
+        scope = ['https://www.googleapis.com/auth/spreadsheets.readonly']
+
+        cred = ServiceAccountCredentials.from_json_keyfile_name(credentials, scope)
+        
+        service = build('sheets', 'v4', credentials=cred)
+    
+        sheet = service.spreadsheets()
+        
+        result_input = sheet.values().get(spreadsheetId=SAMPLE_SPREADSHEET_ID_input,
+                                          range='A1:WWW500000').execute()
+        
+        values_input = result_input.get('values', [])
+        
+        df = pd.DataFrame(values_input[1:], columns=values_input[0])
 
     return df
 
@@ -184,10 +206,10 @@ def read_google_ads(start_date, end_date,
                   admin_account = {'Be You': '291-824-5921'
                                  ,'Humable': '760-045-3647'
                                  ,'Linkers': '504-714-3560'
-                                 ,'Miss Tariffa': '605-298-4997'
                                  ,'Miss Tariffa Agency': '427-886-1215'
                                  ,'Numbers': '794-577-9076'
                                  ,'Wearefiber': '778-681-5313'
+                                  ,'ELLEGIEFFE SRL':'643-277-1546'
                                 },
                    
                    yaml_file_path = 'googleads.yaml'):
